@@ -1,14 +1,15 @@
 package App::wordlist;
 
-our $DATE = '2018-03-22'; # DATE
-our $VERSION = '0.266'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-01'; # DATE
+our $DIST = 'App-wordlist'; # DIST
+our $VERSION = '0.267'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use List::Util qw(shuffle);
-use WordList::Namespace qw(is_actual_wordlist_module);
 
 our %SPEC;
 
@@ -47,27 +48,8 @@ sub _list_installed {
         });
     my @res;
     for my $wl0 (sort keys %$mods) {
-        next unless is_actual_wordlist_module($wl0);
         (my $wl = $wl0) =~ s/\AWordList:://;
 
-        my $type;
-        if ($wl =~ /^(Base|MetaSyntactic)\z/) {
-            # just a base class
-            next;
-        } elsif ($wl =~ s/^MetaSyntactic:://) {
-            $type = 'MetaSyntactic';
-        } elsif ($wl =~ s/^Char:://) {
-            $type = 'Char';
-        } elsif ($wl =~ s/^Phrase:://) {
-            $type = 'Phrase';
-        } elsif ($wl =~ s/^Password:://) {
-            $type = 'Password';
-        } elsif ($wl =~ s/^Test:://) {
-            $type = 'Test';
-        } else {
-            $type = 'Word';
-        }
-
         my $lang = '';
         if ($wl =~ /^(\w\w)::/) {
             $lang = $1;
@@ -76,7 +58,6 @@ sub _list_installed {
         push @res, {
             name => $wl,
             lang => $lang,
-            type => $type,
         };
      }
     \@res;
@@ -148,37 +129,24 @@ $SPEC{wordlist} = {
             description => <<'_',
 
 When listing installed modules (`-l`), this means also returning a wordlist's
-type and language.
+language.
 
 When returning grep result, this means also returning wordlist name.
 
 _
             schema  => 'bool',
         },
-        types => {
-            summary => 'Only include wordlists of certain type(s)',
-            description => <<'_',
-
-By convention, type information is encoded in the wordlist's name. `Char` means
-to only include wordlists with names matching `Char::*`. `Phrase` means to only
-include wordlists with names matching `Phrase::*`. `Word` means to only include
-wordlists that are not of type `Char` and `Phrase`. `Test` means to only include
-wordlists with names matching `Test::*`.
-
-_
-            schema => ['array*', of => ['str*', in=>['Base', 'MetaSyntactic', 'Char', 'Phrase', 'Word', 'Test']]],
-            description => <<'_',
-
-By convention, language information is encoded in the wordlist's name. For
-example, English wordlists have names matching `EN::*` or `Word::EN::*` or
-`Char::EN::*` or `Phrase::EN::*`.
-
-_
-            cmdline_aliases => {t=>{}},
-        },
         langs => {
             'x.name.is_plural' => 1,
             summary => 'Only include wordlists of certain language(s)',
+            description => <<'_',
+
+By convention, language code is the first subnamespace of a wordlist module,
+e.g. WordList::EN::* for English, WordList::FR::* for French, and so on.
+Wordlist modules which do not follow this convention (e.g. WordList::Password::*
+or WordList::PersonName::*) are not included.
+
+_
             schema => ['array*', of => ['str*', match => '\A\w\w\z']],
             element_completion => sub {
                 my %args = @_;
@@ -230,12 +198,12 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
-        {
-            argv => [qw/-t Phrase foo/],
-            summary => 'Select phrase wordlists (multiple -t allowed)',
-            test => 0,
-            'x.doc.show_result' => 0,
-        },
+        #{
+        #    argv => [qw/-t Phrase foo/],
+        #    summary => 'Select phrase wordlists (multiple -t allowed)',
+        #    test => 0,
+        #    'x.doc.show_result' => 0,
+        #},
         {
             argv => [qw/--lang FR foo/],
             summary => 'Select French wordlists (multiple --lang allowed)',
@@ -302,9 +270,6 @@ sub wordlist {
         } else {
             $wordlists = [];
             for my $rec (@$list_installed) {
-                if ($args{types} && @{ $args{types} }) {
-                    next unless grep { $rec->{type} eq $_ } @{$args{types}};
-                }
                 if ($args{langs} && @{ $args{langs} }) {
                     next unless grep { $rec->{lang} eq uc($_) } @{$args{langs}};
                 }
@@ -474,7 +439,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.266 of App::wordlist (from Perl distribution App-wordlist), released on 2018-03-22.
+This document describes version 0.267 of App::wordlist (from Perl distribution App-wordlist), released on 2020-05-01.
 
 =head1 SYNOPSIS
 
@@ -487,7 +452,7 @@ See the included script L<wordlist>.
 
 Usage:
 
- wordlist(%args) -> [status, msg, result, meta]
+ wordlist(%args) -> [status, msg, payload, meta]
 
 Grep words from WordList::*.
 
@@ -499,11 +464,11 @@ Examples:
 
  wordlist();
 
-=item * Print all words matching /foo/ and /bar/:
+=item * Print all words matching E<sol>fooE<sol> and E<sol>barE<sol>:
 
  wordlist( arg => ["foo", "bar"]);
 
-=item * Print all words matching /foo/ or /bar/:
+=item * Print all words matching E<sol>fooE<sol> or E<sol>barE<sol>:
 
  wordlist( arg => ["foo", "bar"], or => 1);
 
@@ -515,10 +480,6 @@ Examples:
 
  wordlist( arg => ["foo"], wordlists => ["ID::KBBI"]);
 
-=item * Select phrase wordlists (multiple -t allowed):
-
- wordlist( arg => ["foo"], types => ["Phrase"]);
-
 =item * Select French wordlists (multiple --lang allowed):
 
  wordlist( arg => ["foo"], langs => ["FR"]);
@@ -549,14 +510,14 @@ Arguments ('*' denotes required arguments):
 
 =item * B<color> => I<str> (default: "auto")
 
-When to highlight search string/matching pattern with color.
+When to highlight search stringE<sol>matching pattern with color.
 
 =item * B<detail> => I<bool>
 
-Display more information when listing modules/result.
+Display more information when listing modulesE<sol>result.
 
 When listing installed modules (C<-l>), this means also returning a wordlist's
-type and language.
+language.
 
 When returning grep result, this means also returning wordlist name.
 
@@ -566,6 +527,11 @@ When returning grep result, this means also returning wordlist name.
 
 Only include wordlists of certain language(s).
 
+By convention, language code is the first subnamespace of a wordlist module,
+e.g. WordList::EN::* for English, WordList::FR::* for French, and so on.
+Wordlist modules which do not follow this convention (e.g. WordList::Password::*
+or WordList::PersonName::*) are not included.
+
 =item * B<lcpan> => I<bool>
 
 Use local CPAN mirror first when available (for -L).
@@ -588,18 +554,11 @@ Match any word in query instead of the default "all".
 
 Pick random words (must set --num to positive number).
 
-=item * B<types> => I<array[str]>
-
-Only include wordlists of certain type(s).
-
-By convention, language information is encoded in the wordlist's name. For
-example, English wordlists have names matching C<EN::*> or C<Word::EN::*> or
-C<Char::EN::*> or C<Phrase::EN::*>.
-
 =item * B<wordlists> => I<array[str]>
 
 Select one or more wordlist modules.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -607,7 +566,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -650,7 +609,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
